==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v2/model/security_monitoring_signal_list_request_filter.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v2.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


class SecurityMonitoringSignalListRequestFilter(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "_from": (datetime,),
            "query": (str,),
            "to": (datetime,),
        }

    attribute_map = {
        "_from": "from",
        "query": "query",
        "to": "to",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Search filters for listing security signals.

        :param _from: The minimum timestamp for requested security signals.
        :type _from: datetime, optional

        :param query: Search query for listing security signals.
        :type query: str, optional

        :param to: The maximum timestamp for requested security signals.
        :type to: datetime, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SecurityMonitoringSignalListRequestFilter, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-2.17.0.tar.gz: datadog-api-client-2.17.0/src/datadog_api_client/v2/model/security_monitoring_signal_list_request_filter.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class SecurityMonitoringSignalListRequestFilter(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "_from": (datetime,),
            "query": (str,),
            "to": (datetime,),
        }

    attribute_map = {
        "_from": "from",
        "query": "query",
        "to": "to",
    }

    def __init__(
        self_,
        _from: Union[datetime, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        to: Union[datetime, UnsetType] = unset,
        **kwargs,
    ):
        """
        Search filters for listing security signals.

        :param _from: The minimum timestamp for requested security signals.
        :type _from: datetime, optional

        :param query: Search query for listing security signals.
        :type query: str, optional

        :param to: The maximum timestamp for requested security signals.
        :type to: datetime, optional
        """
        if _from is not unset:
            kwargs["_from"] = _from
        if query is not unset:
            kwargs["query"] = query
        if to is not unset:
            kwargs["to"] = to
        super().__init__(kwargs)
